from flask_wtf import FlaskForm
from flask_login import current_user
from wtforms import StringField, PasswordField, SubmitField, TextAreaField
from wtforms.validators import DataRequired, EqualTo, ValidationError, Regexp, Length, Email
from blog.models import User

class RegistrationForm(FlaskForm):
  email = StringField('Email',validators=[DataRequired(), Email()])
  username = StringField('Username',validators=[DataRequired(), Length(min=2, max=11),Regexp('^[a-z]{4,11}$')])
  password = PasswordField('Password',validators=[DataRequired()])
  submit = SubmitField('Register')
  def validate_username(self, username):
    user = User.query.filter_by(username=username.data).first()
    if user is not None:
      raise ValidationError('Username already exist. Please choose a different one.')
  def validate_email(self, email):
    user = User.query.filter_by(email=email.data).first()
    if user is not None:
      raise ValidationError('This email is already in use. Please use a different one.')



class LoginForm(FlaskForm):
  email = StringField('Email',validators=[DataRequired()])
  username = StringField('Username',validators=[DataRequired()])
  password = PasswordField('Password',validators=[DataRequired()])
  submit = SubmitField('Login')

class UpdateAccountForm(FlaskForm):
  email = StringField('Email',validators=[DataRequired(), Email()])
  username = StringField('Username',validators=[DataRequired(), Length(min=2, max=11)])
  password = PasswordField('Password',validators=[DataRequired()])
  submit = SubmitField('Update')
  def validate_username(self, username):
    if username.data != current_user.username:
      user = User.query.filter_by(username=username.data).first()
      if user:
        raise ValidationError('That username is in use. Please try again')
  def validate_email(self, email):
    if email.data != current_user.email:
      user = User.query.filter_by(email=email.data).first()
      if user:
        raise ValidationError('That email is in use. Please try again')

class PostForm(FlaskForm):
  title = StringField('Title', validators=[DataRequired()])
  content = TextAreaField('Content', validators=[DataRequired()])
  submit = SubmitField('Post')